@@ -11,12 +11,12 @@ import os
 
 class Notifications:
     logger = None
-    base_notif_url = os.environ.get("NOTIFICATIONS_API", None)
+    base_notif_url = os.environ.get("NOTIFICATIONS_API", "")
     headers = None
 
     def __init__(self, logger=None):
         self.headers = {
-            "Authorization": f'token {os.environ.get("JUPYTERHUB_API_TOKEN", None)}'
+            "Authorization": f'token {os.environ.get("JUPYTERHUB_API_TOKEN", "")}'
         }
         self.logger = logger
 
@@ -61,7 +61,6 @@ class Notifications:
             req.raise_for_status()
             jsn = req.json()
             print("👌 💌 Email has been sent successfully !")
-            return jsn
         except Exception as err:
             if self.logger is not None:
                 self.logger.error(
@@ -88,8 +87,8 @@ class Notifications:
             else:
                 print(jsn)
             return jsn
-        base_url = os.environ.get("JUPYTERHUB_URL", None)
-        base_user = os.environ.get("JUPYTERHUB_USER", None)
+        base_url = os.environ.get("JUPYTERHUB_URL", "")
+        base_user = os.environ.get("JUPYTERHUB_USER", "")
         content = ""
         file_link = f"{base_url}/user/{base_user}/tree/{file_path}"
         if current_type == t_asset or current_type == t_notebook:
